==> pycsp3-1.0.4.tar.gz: pycsp3-1.0.4/pycsp3/problems/tests/g4_world.py <==
from pycsp3.problems.tests.tester import Tester, run

NAME = "g4_world"

diff = (Tester(NAME)
        .add("Tal", data="Tal-frobserved-7-15-11-13-9-1-11-7-4_1.json")
        .add("SolitaireBattleship", data="SolitaireBattleship-battleship_instances-00113.json")
        # Ordre des groups dans un block
        .add("TravelingPurchaser", data="TravelingPurchaser-7-5-30-1.json", variant="elt")  # je detecte deux colonnes égales, JvCSP, non
        )

same = (Tester(NAME)
        .add("SchedulingJS", data="Taillard-js-015-15-1.json")
        .add("SchedulingJS", data="Sadeh-js-e0ddr1-0.json")
        .add("SchedulingOS", data="Taillard-os-05-05-1.json")
        .add("SchedulingOS", data="GP-os-01.json")
        .add("SchedulingFS", data="Taillard-fs-020-05-1.json")
        .add("SchedulingFS", data="SchedulingFS-Taillard-os-04-04-0.json")
        .add("Fapp", data="Fapp_ex2.json")
        .add("Fapp", data="Fapp_ex2.json", variant="short")
        # .add("Fapp", data="Fapp_01-0200.json")  # TODO too long (and seems to crash)
        # .add("Fapp", data="Fapp_01-0200.json", variant="short")
        .add("Bacp", data="Bacp_inst0.json", variant="m1")
        .add("Bacp", data="Bacp_inst0.json", variant="m2")
        .add("Bacp", data="Bacp_inst0.json", variant="m1-d")
        .add("Bacp", data="Bacp_inst0.json", variant="m2-d")
        .add("Bacp", data="Bacp_10.mzn", variant="m1", prs_py="Bacp_ParserZ", prs_jv="Bacp_ParserZ")  # m1 is enough to test parsing
        .add("CarSequencing", data="CarSequencing_dingbas.json")
        .add("Crossword", data="Crossword_vg6-7-ogd.json")
        .add("Crossword", data="Crossword_h1501-lex.json")
        .add("Crossword", data="Crossword_h0504-lex.json", variant="alt")
        .add("League", data="League_010-03-04.json")
        .add("League", data="League_010-03-04.json", variant="01")
        .add("MisteryShopper", data="MisteryShopper_04.json")
        .add("NurseRostering", data="NurseRostering_00.json")
        .add("NurseRostering", data="NurseRostering_18.json")
        .add("PizzaVoucher", data="PizzaVoucher_pizza6.json")
        .add("QuadraticAssignment", data="QuadraticAssignment_qap.json")
        .add("QuadraticAssignment", data="QuadraticAssignment_example.txt", prs_py="QuadraticAssignment_Parser", prs_jv="QuadraticAssignment_Parser")
        .add("Rack", data="Rack_r2.json")
        .add("Rack2", data="Rack_r2b.json")
        .add("RadarSurveillance", data="RadarSurveillance_8-24-3-2-00.json")
        .add("Rcpsp", data="Rcpsp_j30-01-01.json")
        .add("Rlfap", data="Rlfap_card-scen-04.json", variant="card")
        .add("Rlfap", data="Rlfap_span-scen-05.json", variant="span")
        .add("SolitaireBattleship", data="SolitaireBattleship_sb-12-12-5-0.json")
        .add("SteelMillSlab", data="SteelMillSlab_bench_2_0.json")
        .add("SteelMillSlab", data="SteelMillSlab_bench_2_0.json", variant="01")
        .add("TemplateDesign", data="TemplateDesign_catfood_2.json")
        .add("TemplateDesign", data="TemplateDesign_catfood_2.json", variant="aux")
        .add("TravelingTournament", data="TravelingTournament_galaxy04.json", variant="a2")
        .add("TravelingTournament", data="TravelingTournament_galaxy04.json", variant="a3")
        .add("TravelingTournamentWithPredefinedVenues", data="Ttppv_circ8bbal.json", variant="a2")
        .add("TravelingTournamentWithPredefinedVenues", data="Ttppv_circ8bbal.json", variant="a3")
        .add("Vrp", data="Vrp_P-n16-k8.json")
        .add("Warehouse", data="Warehouse_example.txt", prs_py="Warehouse_Parser", prs_jv="Warehouse_Parser")
        .add("Wwtpp", data="Wwtpp_ex04400.json")
        .add("Wwtpp", data="Wwtpp_ex04400.json", variant="short")
        )

xcsp = (Tester(NAME)
        .add(same.instances)
        )

run(diff, same, xcsp)

==> pycsp3-1.0.7.tar.gz: pycsp3-1.0.7/pycsp3/problems/tests/g4_world.py <==
from pycsp3.problems.tests.tester import Tester, run

NAME = "g4_world"

diff = (Tester(NAME)
        .add("SolitaireBattleship", data="SolitaireBattleship-battleship_instances-00113.json")  # different order of groups in a block
        .add("Tal", data="Tal-frobserved-7-15-11-13-9-1-11-7-4_1.json")
        .add("TravelingPurchaser", data="TravelingPurchaser-7-5-30-1.json", variant="elt")  # intension constraints more compact in PyCSP
        )

same = (Tester(NAME)
        .add("Bacp", data="Bacp_inst0.json", variant="m1")
        .add("Bacp", data="Bacp_inst0.json", variant="m2")
        .add("Bacp", data="Bacp_inst0.json", variant="m1-d")
        .add("Bacp", data="Bacp_inst0.json", variant="m2-d")
        .add("Bacp", data="Bacp_10.mzn", variant="m1", prs_py="Bacp_ParserZ", prs_jv="Bacp_ParserZ")  # m1 is enough to test parsing
        .add("CarSequencing", data="CarSequencing_dingbas.json")
        .add("Crossword", data="Crossword_vg6-7-ogd.json")
        .add("Crossword", data="Crossword_h1501-lex.json")
        .add("Crossword", data="Crossword_h0504-lex.json", variant="alt")
        .add("Fapp", data="Fapp_ex2.json")
        .add("Fapp", data="Fapp_ex2.json", variant="short")
        # .add("Fapp", data="Fapp_01-0200.json")  # TODO too long (and seems to crash)
        # .add("Fapp", data="Fapp_01-0200.json", variant="short")
        .add("League", data="League_010-03-04.json")
        .add("League", data="League_010-03-04.json", variant="01")
        .add("MisteryShopper", data="MisteryShopper_04.json")
        .add("NurseRostering", data="NurseRostering_00.json")
        .add("NurseRostering", data="NurseRostering_18.json")
        .add("PizzaVoucher", data="PizzaVoucher_pizza6.json")
        .add("QuadraticAssignment", data="QuadraticAssignment_qap.json")
        .add("QuadraticAssignment", data="QuadraticAssignment_example.txt", prs_py="QuadraticAssignment_Parser", prs_jv="QuadraticAssignment_Parser")
        .add("Rack", data="Rack_r2.json")
        .add("Rack2", data="Rack_r2b.json")
        .add("RadarSurveillance", data="RadarSurveillance_8-24-3-2-00.json")
        .add("Rcpsp", data="Rcpsp_j30-01-01.json")
        .add("Rlfap", data="Rlfap_card-scen-04.json", variant="card")
        .add("Rlfap", data="Rlfap_span-scen-05.json", variant="span")
        .add("SchedulingJS", data="Taillard-js-015-15-1.json")
        .add("SchedulingJS", data="Sadeh-js-e0ddr1-0.json")
        .add("SchedulingOS", data="Taillard-os-05-05-1.json")
        .add("SchedulingOS", data="GP-os-01.json")
        .add("SchedulingFS", data="Taillard-fs-020-05-1.json")
        .add("SchedulingFS", data="SchedulingFS-Taillard-os-04-04-0.json")
        .add("SolitaireBattleship", data="SolitaireBattleship_sb-12-12-5-0.json")
        .add("SteelMillSlab", data="SteelMillSlab_bench_2_0.json")
        .add("SteelMillSlab", data="SteelMillSlab_bench_2_0.json", variant="01")
        .add("TemplateDesign", data="TemplateDesign_catfood_2.json")
        .add("TemplateDesign", data="TemplateDesign_catfood_2.json", variant="aux")
        .add("TravelingTournament", data="TravelingTournament_galaxy04.json", variant="a2")
        .add("TravelingTournament", data="TravelingTournament_galaxy04.json", variant="a3")
        .add("TravelingTournamentWithPredefinedVenues", data="Ttppv_circ8bbal.json", variant="a2")
        .add("TravelingTournamentWithPredefinedVenues", data="Ttppv_circ8bbal.json", variant="a3")
        .add("Vrp", data="Vrp_P-n16-k8.json")
        .add("Warehouse", data="Warehouse_example.txt", prs_py="Warehouse_Parser", prs_jv="Warehouse_Parser")
        .add("Wwtpp", data="Wwtpp_ex04400.json")
        .add("Wwtpp", data="Wwtpp_ex04400.json", variant="short")
        )

xcsp = (Tester(NAME)
        .add(same.instances)
        )

run(diff, same, xcsp)
